"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[3009],{45223:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o=l(a(92649)),u=l(a(51396)),f=l(a(60750)),n=l(a(20718)),s=l(a(25578)),d={code:"nl",formatDistance:o.default,formatLong:u.default,formatRelative:f.default,localize:n.default,match:s.default,options:{weekStartsOn:1,firstWeekContainsDate:4}};t.default=d,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-nl-index-js.js.map