"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[4071],{19805:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o=l(a(49223)),s=l(a(66978)),u=l(a(55480)),f=l(a(30760)),d=l(a(44176)),n={code:"es",formatDistance:o.default,formatLong:s.default,formatRelative:u.default,localize:f.default,match:d.default,options:{weekStartsOn:1,firstWeekContainsDate:1}};t.default=n,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-es-index-js.js.map