"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[663],{17081:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o=l(a(70003)),u=l(a(23582)),f=l(a(75052)),s=l(a(70548)),d=l(a(15540)),n={code:"lt",formatDistance:o.default,formatLong:u.default,formatRelative:f.default,localize:s.default,match:d.default,options:{weekStartsOn:1,firstWeekContainsDate:4}};t.default=n,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-lt-index-js.js.map