"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[9971],{29307:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o=l(a(36589)),u=l(a(44616)),f=l(a(16042)),n=l(a(76370)),s=l(a(74774)),d={code:"nl-BE",formatDistance:o.default,formatLong:u.default,formatRelative:f.default,localize:n.default,match:s.default,options:{weekStartsOn:1,firstWeekContainsDate:4}};t.default=d,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-nl-BE-index-js.js.map