"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[7825],{39946:(e,n,t)=>{t.r(n),t.d(n,{allPathsLoader:()=>r});var s=t(31635),r=function(e,n){return(0,s.sH)(void 0,void 0,void 0,(function(){return(0,s.YH)(this,(function(s){switch(s.label){case 0:return[4,Promise.all([t.e(5288),t.e(23)]).then(t.bind(t,39803))];case 1:return[2,(0,s.sent().getIconPaths)(e,n)]}}))}))}}}]);
//# sourceMappingURL=async-blueprint-icons-all-paths-loader.js.map