"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[4558],{9478:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o=l(a(88876)),s=l(a(99405)),u=l(a(18367)),f=l(a(70287)),n=l(a(74033)),d={code:"sr-Latn",formatDistance:o.default,formatLong:s.default,formatRelative:u.default,localize:f.default,match:n.default,options:{weekStartsOn:1,firstWeekContainsDate:1}};t.default=d,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-sr-Latn-index-js.js.map