"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[6917],{86309:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o=l(a(91287)),u=l(a(26376)),f=l(a(12568)),n=l(a(85024)),s=l(a(30730)),d={code:"en-NZ",formatDistance:o.default,formatLong:s.default,formatRelative:u.default,localize:f.default,match:n.default,options:{weekStartsOn:1,firstWeekContainsDate:4}};t.default=d,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-en-NZ-index-js.js.map