"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[4656],{20006:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var u=l(a(52140)),o=l(a(30029)),f=l(a(7775)),s=l(a(48047)),d=l(a(39601)),n={code:"hu",formatDistance:u.default,formatLong:o.default,formatRelative:f.default,localize:s.default,match:d.default,options:{weekStartsOn:1,firstWeekContainsDate:4}};t.default=n,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-hu-index-js.js.map