@font-face{
  font-family:"blueprint-icons-16";
  src:url("./blueprint-icons-16.ttf?ec6513420d7320fe9d6afb75ca586af5") format("truetype"), url("./blueprint-icons-16.eot?ec6513420d7320fe9d6afb75ca586af5#iefix") format("embedded-opentype"), url("./blueprint-icons-16.woff2?ec6513420d7320fe9d6afb75ca586af5") format("woff2"), url("./blueprint-icons-16.woff?ec6513420d7320fe9d6afb75ca586af5") format("woff"), url("./blueprint-icons-16.svg?ec6513420d7320fe9d6afb75ca586af5#blueprint-icons-16") format("svg");
}
@font-face{
  font-family:"blueprint-icons-20";
  src:url("./blueprint-icons-20.ttf?c4b75bae44f3d7c4a42635f60927e172") format("truetype"), url("./blueprint-icons-20.eot?c4b75bae44f3d7c4a42635f60927e172#iefix") format("embedded-opentype"), url("./blueprint-icons-20.woff2?c4b75bae44f3d7c4a42635f60927e172") format("woff2"), url("./blueprint-icons-20.woff?c4b75bae44f3d7c4a42635f60927e172") format("woff"), url("./blueprint-icons-20.svg?c4b75bae44f3d7c4a42635f60927e172#blueprint-icons-20") format("svg");
}