"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[3322],{30999:(e,n,t)=>{t.r(n),t.d(n,{splitPathsBySizeLoader:()=>i});var s=t(31635),r=t(43261),a=t(6134),i=function(e,n){return(0,s.sH)(void 0,void 0,void 0,(function(){var i,u;return(0,s.YH)(this,(function(s){switch(s.label){case 0:return i=(0,r.fL)(e),n!==a.l.STANDARD?[3,2]:[4,t.e(5288).then(t.bind(t,96251))];case 1:return u=s.sent(),[3,4];case 2:return[4,t.e(5288).then(t.bind(t,95204))];case 3:u=s.sent(),s.label=4;case 4:return[2,u[i]]}}))}))}}}]);
//# sourceMappingURL=async-blueprint-icons-split-paths-by-size-loader.js.map